==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/people/classes/legacy/UsersFieldsConfig.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array();
use Claromentis\Core\Services;
use Claromentis\People\UserFieldsConfigService;








class UsersFieldsConfig
{
    protected static $service;
    
    
    
    
    protected static function I()
    {
        if (!isset(self::$service)) {
            self::$service = Services::I()->{UserFieldsConfigService::class};
        }
        return self::$service;
    }
    
    
    
    
    
    
    
    
    public static function SplitName($_66dc8b21e839a9a4739443a621ecc45a)
    {
        return self::I()->SplitName($_66dc8b21e839a9a4739443a621ecc45a);
    }
    
    
    
    
    
    
    public static function GetFieldsUsersList()
    {
        return self::I()->GetFieldsUsersList();
    }
    
    
    
    
    
    
    public static function GetFieldsAdvancedSearch()
    {
        return self::I()->GetFieldsAdvancedSearch();
    }
    
    
    
    
    
    
    public static function GetFieldsViewProfile()
    {
        return self::I()->GetFieldsViewProfile();
    }
    
    
    
    
    
    
    public static function GetFieldsViewProfileTop()
    {
        return self::I()->GetFieldsViewProfileTop();
    }
    
    
    
    
    
    
    
    public static function GetFieldsMyProfile($_47af7de043bd427b3a09c87f0ae4b98e = false)
    {
        return self::I()->GetFieldsMyProfile($_47af7de043bd427b3a09c87f0ae4b98e);
    }
    
    
    
    
    
    
    
    public static function GetFieldsOthersProfile($_08ed628ce92f9e6a4bda45cab14cbb15)
    {
        return self::I()->GetFieldsOthersProfile($_08ed628ce92f9e6a4bda45cab14cbb15);
    }
    
    
    
    
    
    
    
    public static function GetFieldsAdminProfile($_47af7de043bd427b3a09c87f0ae4b98e = false)
    {
        return self::I()->GetFieldsAdminProfile($_47af7de043bd427b3a09c87f0ae4b98e);
    }
    
    
    
    
    
    
    public static function GetFieldsAdminList()
    {
        return self::I()->GetFieldsAdminList();
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/people/classes/legacy/UsersFieldsConfig.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array();
use Claromentis\Core\Services;
use Claromentis\People\UserFieldsConfigService;








class UsersFieldsConfig
{
    protected static $service;
    
    
    
    
    protected static function I()
    {
        if (!isset(self::$service)) {
            self::$service = Services::I()->{UserFieldsConfigService::class};
        }
        return self::$service;
    }
    
    
    
    
    
    
    
    
    public static function SplitName($_66dc8b21e839a9a4739443a621ecc45a)
    {
        return self::I()->SplitName($_66dc8b21e839a9a4739443a621ecc45a);
    }
    
    
    
    
    
    
    public static function GetFieldsUsersList()
    {
        return self::I()->GetFieldsUsersList();
    }
    
    
    
    
    
    
    public static function GetFieldsAdvancedSearch()
    {
        return self::I()->GetFieldsAdvancedSearch();
    }
    
    
    
    
    
    
    public static function GetFieldsViewProfile()
    {
        return self::I()->GetFieldsViewProfile();
    }
    
    
    
    
    
    
    public static function GetFieldsViewProfileTop()
    {
        return self::I()->GetFieldsViewProfileTop();
    }
    
    
    
    
    
    
    
    public static function GetFieldsMyProfile($_47af7de043bd427b3a09c87f0ae4b98e = false)
    {
        return self::I()->GetFieldsMyProfile($_47af7de043bd427b3a09c87f0ae4b98e);
    }
    
    
    
    
    
    
    
    public static function GetFieldsOthersProfile($_08ed628ce92f9e6a4bda45cab14cbb15)
    {
        return self::I()->GetFieldsOthersProfile($_08ed628ce92f9e6a4bda45cab14cbb15);
    }
    
    
    
    
    
    
    
    public static function GetFieldsAdminProfile($_47af7de043bd427b3a09c87f0ae4b98e = false)
    {
        return self::I()->GetFieldsAdminProfile($_47af7de043bd427b3a09c87f0ae4b98e);
    }
    
    
    
    
    
    
    public static function GetFieldsAdminList()
    {
        return self::I()->GetFieldsAdminList();
    }
}
